BushaPayError class

An error occurred during checkout.

Inheritance

Constructors

BushaPayError({required String message, String? code})
const

Properties

code String?
Error code, if available.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited