BushaPayResult class sealed

Result of a Busha Pay checkout.

Use pattern matching to handle each case:

switch (result) {
  case BushaPaySuccess(:final paymentId):
    print('Payment $paymentId completed');
  case BushaPayCancelled():
    print('User cancelled');
  case BushaPayError(:final message):
    print('Error: $message');
}
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited