hasFullData property
bool
get
hasFullData
Whether full payment data is available.
true when payment completed in the web checkout (Path A).
false when payment completed via the Busha app (Path B).
Implementation
bool get hasFullData => rawData != null;